@@ -7,50 +7,48 @@
 #' @param a  is one of the regression coefficients of SAFER algorithm
 #' @param b  is one of the regression coefficients of SAFER algorithm
 #' @export
-#' @import raster
-#' @import sp
-#' @import rgdal
+#' @import terra
 #' @importFrom utils read.csv
 #'
 #' @return It returns in raster format (.tif) the Surface Albedo at 24h scale ("Alb_24"), NDVI, Surface Temperature ("LST"), Crop Coefficient ("kc") and net radiation ("Rn_MJ").
 
 kc_l8t_grid = function(doy, a, b){
 
-  b1 <- raster("B1.tif")
-  b2 <- raster("B2.tif")
-  b3 <- raster("B3.tif")
-  b4 <- raster("B4.tif")
-  b5 <- raster("B5.tif")
-  b6 <- raster("B6.tif")
-  b7 <- raster("B7.tif")
-  b10 <- raster("B10.tif")
-  b11 <- raster("B11.tif")
-  RG <- raster("RG.tif")
-  Ta <- raster("Ta.tif")
+  b1 <- rast("B1.tif")
+  b2 <- rast("B2.tif")
+  b3 <- rast("B3.tif")
+  b4 <- rast("B4.tif")
+  b5 <- rast("B5.tif")
+  b6 <- rast("B6.tif")
+  b7 <- rast("B7.tif")
+  b10 <- rast("B10.tif")
+  b11 <- rast("B11.tif")
+  RG <- rast("RG.tif")
+  Ta <- rast("Ta.tif")
 
-  mask <- readOGR("mask.shp")
+  mask <- vect("mask.shp")
 
-  b1_crop <- crop(b1, extent(mask))
+  b1_crop <- crop(b1, ext(mask)[1:4])
   b1_mascara <- mask(b1_crop, mask)
-  b2_crop <- crop(b2, extent(mask))
+  b2_crop <- crop(b2, ext(mask)[1:4])
   b2_mascara <- mask(b2_crop, mask)
-  b3_crop <- crop(b3, extent(mask))
+  b3_crop <- crop(b3, ext(mask)[1:4])
   b3_mascara <- mask(b3_crop, mask)
-  b4_crop <- crop(b4, extent(mask))
+  b4_crop <- crop(b4, ext(mask)[1:4])
   b4_mascara <- mask(b4_crop, mask)
-  b5_crop <- crop(b5, extent(mask))
+  b5_crop <- crop(b5, ext(mask)[1:4])
   b5_mascara <- mask(b5_crop, mask)
-  b6_crop <- crop(b6, extent(mask))
+  b6_crop <- crop(b6, ext(mask)[1:4])
   b6_mascara <- mask(b6_crop, mask)
-  b7_crop <- crop(b7, extent(mask))
+  b7_crop <- crop(b7, ext(mask)[1:4])
   b7_mascara <- mask(b7_crop, mask)
-  b10_crop <- crop(b10, extent(mask))
+  b10_crop <- crop(b10, ext(mask)[1:4])
   b10_mascara <- mask(b10_crop, mask)
-  b11_crop <- crop(b11, extent(mask))
+  b11_crop <- crop(b11, ext(mask)[1:4])
   b11_mascara <- mask(b11_crop, mask)
-  RG_crop <- crop(RG, extent(mask))
+  RG_crop <- crop(RG, ext(mask)[1:4])
   RG <- mask(RG_crop, mask)
-  Ta_crop <- crop(Ta, extent(mask))
+  Ta_crop <- crop(Ta, ext(mask)[1:4])
   Ta <- mask(Ta_crop, mask)
 
   metadata <- list.files(pattern = "txt")
@@ -166,11 +164,11 @@ kc_l8t_grid = function(doy, a, b){
   b11_mascara = ((RADIANCE_MAXIMUM_BAND_11-RADIANCE_MINIMUM_BAND_11)/65535)*b11_mascara+(RADIANCE_MINIMUM_BAND_11)
 
   lati <- long <- b2_mascara
-  xy <- coordinates(b2_mascara)
+  xy <- crds(b2_mascara)
   long[] <- xy[, 1]
-  long <- crop(long, extent(mask))
+  long <- crop(long, ext(mask)[1:4])
   lati[] <- xy[, 2]
-  lati <- crop(lati, extent(mask))
+  lati <- crop(lati, ext(mask)[1:4])
 
   map1 <- (long/long)*((2*pi)/365)*(doy-1)
 
@@ -221,11 +219,11 @@ kc_l8t_grid = function(doy, a, b){
   Alb_24 =  1.0223*Alb_sur + 0.0149
 
 
-  writeRaster(Alb_24, "Alb_24", format = "GTiff", overwrite=TRUE)
+  writeRaster(Alb_24, "Alb_24", filetype = "GTiff", overwrite=TRUE)
 
   NDVI =(b5_mascara-b4_mascara)/(b5_mascara+b4_mascara)
 
-  writeRaster(NDVI, "NDVI", format = "GTiff", overwrite=TRUE)
+  writeRaster(NDVI, "NDVI", filetype = "GTiff", overwrite=TRUE)
 
   Ws = acos(((-1)*tan(lati*pi/180))*tan(Dec))
 
@@ -245,7 +243,7 @@ kc_l8t_grid = function(doy, a, b){
 
   TS24 = 1.0694*Tbright-20.173
 
-  writeRaster(TS24, "LST", format = "GTiff", overwrite=TRUE)
+  writeRaster(TS24, "LST", filetype = "GTiff", overwrite=TRUE)
 
   Transm =(RG*11.6)/RsTOP
 
@@ -255,7 +253,7 @@ kc_l8t_grid = function(doy, a, b){
 
   Rn_MJ =Rn/11.6
 
-  writeRaster(Rn_MJ, "Rn_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(Rn_MJ, "Rn_MJ", filetype = "GTiff", overwrite=TRUE)
 
   rm(b1, b2, b3, b4, b5, b6, b7, b1_mascara, b2_mascara, b3_mascara, b4_mascara, b5_mascara,b6_mascara,b7_mascara, R, Ws, E0, cos_zwn, W, Dec, LAT, Et, map1, lati, long)
 
@@ -264,7 +262,7 @@ kc_l8t_grid = function(doy, a, b){
 
   kc=exp((a)+(b*((TS24-273.15)/(Alb_sur*NDVI))))
 
-  writeRaster(kc, "kc", format = "GTiff", overwrite=TRUE)
+  writeRaster(kc, "kc", filetype = "GTiff", overwrite=TRUE)
 }
 
 
@@ -273,54 +271,52 @@ kc_l8t_grid = function(doy, a, b){
 #' @param a  is one of the regression coefficients of SAFER algorithm
 #' @param b is one of the regression coefficients of SAFER algorithm
 #' @export
-#' @import raster
-#' @import sp
-#' @import rgdal
+#' @import terra
 #' @importFrom utils read.csv
 #'
 #' @return It returns in raster format (.tif) the Surface Albedo at 24h scale ("Alb_24"), NDVI, Surface Temperature ("LST"), net radiation ("Rn_MJ"), Crop Coefficient ("kc") and Actual Evapotranspiration (evapo).
 
 evapo_l8t_grid = function(doy, a, b){
 
-  b1 <- raster("B1.tif")
-  b2 <- raster("B2.tif")
-  b3 <- raster("B3.tif")
-  b4 <- raster("B4.tif")
-  b5 <- raster("B5.tif")
-  b6 <- raster("B6.tif")
-  b7 <- raster("B7.tif")
-  b10 <- raster("B10.tif")
-  b11 <- raster("B11.tif")
-  RG <- raster("RG.tif")
-  ET0 <- raster("ET0.tif")
-  Ta <- raster("Ta.tif")
+  b1 <- rast("B1.tif")
+  b2 <- rast("B2.tif")
+  b3 <- rast("B3.tif")
+  b4 <- rast("B4.tif")
+  b5 <- rast("B5.tif")
+  b6 <- rast("B6.tif")
+  b7 <- rast("B7.tif")
+  b10 <- rast("B10.tif")
+  b11 <- rast("B11.tif")
+  RG <- rast("RG.tif")
+  ET0 <- rast("ET0.tif")
+  Ta <- rast("Ta.tif")
 
 
-  mask <- readOGR("mask.shp")
+  mask <- vect("mask.shp")
 
-  b1_crop <- crop(b1, extent(mask))
+  b1_crop <- crop(b1, ext(mask)[1:4])
   b1_mascara <- mask(b1_crop, mask)
-  b2_crop <- crop(b2, extent(mask))
+  b2_crop <- crop(b2, ext(mask)[1:4])
   b2_mascara <- mask(b2_crop, mask)
-  b3_crop <- crop(b3, extent(mask))
+  b3_crop <- crop(b3, ext(mask)[1:4])
   b3_mascara <- mask(b3_crop, mask)
-  b4_crop <- crop(b4, extent(mask))
+  b4_crop <- crop(b4, ext(mask)[1:4])
   b4_mascara <- mask(b4_crop, mask)
-  b5_crop <- crop(b5, extent(mask))
+  b5_crop <- crop(b5, ext(mask)[1:4])
   b5_mascara <- mask(b5_crop, mask)
-  b6_crop <- crop(b6, extent(mask))
+  b6_crop <- crop(b6, ext(mask)[1:4])
   b6_mascara <- mask(b6_crop, mask)
-  b7_crop <- crop(b7, extent(mask))
+  b7_crop <- crop(b7, ext(mask)[1:4])
   b7_mascara <- mask(b7_crop, mask)
-  b10_crop <- crop(b10, extent(mask))
+  b10_crop <- crop(b10, ext(mask)[1:4])
   b10_mascara <- mask(b10_crop, mask)
-  b11_crop <- crop(b11, extent(mask))
+  b11_crop <- crop(b11, ext(mask)[1:4])
   b11_mascara <- mask(b11_crop, mask)
-  RG_crop <- crop(RG, extent(mask))
+  RG_crop <- crop(RG, ext(mask)[1:4])
   RG <- mask(RG_crop, mask)
-  ET0_crop <- crop(ET0, extent(mask))
+  ET0_crop <- crop(ET0, ext(mask)[1:4])
   ET0 <- mask(ET0_crop, mask)
-  Ta_crop <- crop(Ta, extent(mask))
+  Ta_crop <- crop(Ta, ext(mask)[1:4])
   Ta <- mask(Ta_crop, mask)
 
   metadata <- list.files(pattern = "txt")
@@ -436,11 +432,11 @@ evapo_l8t_grid = function(doy, a, b){
   b11_mascara = ((RADIANCE_MAXIMUM_BAND_11-RADIANCE_MINIMUM_BAND_11)/65535)*b11_mascara+(RADIANCE_MINIMUM_BAND_11)
 
   lati <- long <- b2_mascara
-  xy <- coordinates(b2_mascara)
+  xy <- crds(b2_mascara)
   long[] <- xy[, 1]
-  long <- crop(long, extent(mask))
+  long <- crop(long, ext(mask)[1:4])
   lati[] <- xy[, 2]
-  lati <- crop(lati, extent(mask))
+  lati <- crop(lati, ext(mask)[1:4])
 
   map1 <- (long/long)*((2*pi)/365)*(doy-1)
 
@@ -491,11 +487,11 @@ evapo_l8t_grid = function(doy, a, b){
   Alb_24 =  1.0223*Alb_sur + 0.0149
 
 
-  writeRaster(Alb_24, "Alb_24", format = "GTiff", overwrite=TRUE)
+  writeRaster(Alb_24, "Alb_24", filetype = "GTiff", overwrite=TRUE)
 
   NDVI =(b5_mascara-b4_mascara)/(b5_mascara+b4_mascara)
 
-  writeRaster(NDVI, "NDVI", format = "GTiff", overwrite=TRUE)
+  writeRaster(NDVI, "NDVI", filetype = "GTiff", overwrite=TRUE)
 
   Ws = acos(((-1)*tan(lati*pi/180))*tan(Dec))
 
@@ -513,7 +509,7 @@ evapo_l8t_grid = function(doy, a, b){
 
   TS24 = 1.0694*Tbright-20.173
 
-  writeRaster(TS24, "LST", format = "GTiff", overwrite=TRUE)
+  writeRaster(TS24, "LST", filetype = "GTiff", overwrite=TRUE)
 
   Transm =(RG*11.6)/RsTOP
 
@@ -523,7 +519,7 @@ evapo_l8t_grid = function(doy, a, b){
 
   Rn_MJ =Rn/11.6
 
-  writeRaster(Rn_MJ, "Rn_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(Rn_MJ, "Rn_MJ", filetype = "GTiff", overwrite=TRUE)
 
   rm(b1, b2, b3, b4, b5, b6, b7, b1_mascara, b2_mascara, b3_mascara, b4_mascara, b5_mascara,b6_mascara,b7_mascara, R, Ws, E0, cos_zwn, W, Dec, LAT, Et, map1, lati, long)
 
@@ -532,11 +528,11 @@ evapo_l8t_grid = function(doy, a, b){
 
   kc=exp((a)+(b*((TS24-273.15)/(Alb_sur*NDVI))))
 
-  writeRaster(kc, "kc", format = "GTiff", overwrite=TRUE)
+  writeRaster(kc, "kc", filetype = "GTiff", overwrite=TRUE)
 
   ET=kc*ET0
 
-  writeRaster(ET, "evapo", format = "GTiff", overwrite=TRUE)
+  writeRaster(ET, "evapo", filetype = "GTiff", overwrite=TRUE)
 }
 
 
@@ -545,9 +541,7 @@ evapo_l8t_grid = function(doy, a, b){
 #'@param a is one of the regression coefficients of SAFER algorithm
 #'@param b is one of the regression coefficients of SAFER algorithm
 #'@export
-#'@import raster
-#' @import sp
-#' @import rgdal
+#' @import terra
 #' @importFrom utils read.csv
 #'
 #'@return It returns in raster format (.tif) the Surface Albedo at 24h scale ("Alb_24"), NDVI, Surface Temperature ("LST"), Crop Coefficient ("kc"), Actual Evapotranspiration (evapo), latent heat flux "LE_MJ"), net radiation ("Rn_MJ"), ground heat flux ("G_MJ") and the sensible heat flux ("H_MJ").
@@ -556,44 +550,44 @@ evapo_l8t_grid = function(doy, a, b){
 radiation_l8t_grid =  function(doy, a, b){
 
 
-  b1 <- raster("B1.tif")
-  b2 <- raster("B2.tif")
-  b3 <- raster("B3.tif")
-  b4 <- raster("B4.tif")
-  b5 <- raster("B5.tif")
-  b6 <- raster("B6.tif")
-  b7 <- raster("B7.tif")
-  b10 <- raster("B10.tif")
-  b11 <- raster("B11.tif")
-  RG <- raster("RG.tif")
-  ET0 <- raster("ET0.tif")
-  Ta <- raster("Ta.tif")
+  b1 <- rast("B1.tif")
+  b2 <- rast("B2.tif")
+  b3 <- rast("B3.tif")
+  b4 <- rast("B4.tif")
+  b5 <- rast("B5.tif")
+  b6 <- rast("B6.tif")
+  b7 <- rast("B7.tif")
+  b10 <- rast("B10.tif")
+  b11 <- rast("B11.tif")
+  RG <- rast("RG.tif")
+  ET0 <- rast("ET0.tif")
+  Ta <- rast("Ta.tif")
 
-  mask <- readOGR("mask.shp")
+  mask <- vect("mask.shp")
 
-  b1_crop <- crop(b1, extent(mask))
+  b1_crop <- crop(b1, ext(mask)[1:4])
   b1_mascara <- mask(b1_crop, mask)
-  b2_crop <- crop(b2, extent(mask))
+  b2_crop <- crop(b2, ext(mask)[1:4])
   b2_mascara <- mask(b2_crop, mask)
-  b3_crop <- crop(b3, extent(mask))
+  b3_crop <- crop(b3, ext(mask)[1:4])
   b3_mascara <- mask(b3_crop, mask)
-  b4_crop <- crop(b4, extent(mask))
+  b4_crop <- crop(b4, ext(mask)[1:4])
   b4_mascara <- mask(b4_crop, mask)
-  b5_crop <- crop(b5, extent(mask))
+  b5_crop <- crop(b5, ext(mask)[1:4])
   b5_mascara <- mask(b5_crop, mask)
-  b6_crop <- crop(b6, extent(mask))
+  b6_crop <- crop(b6, ext(mask)[1:4])
   b6_mascara <- mask(b6_crop, mask)
-  b7_crop <- crop(b7, extent(mask))
+  b7_crop <- crop(b7, ext(mask)[1:4])
   b7_mascara <- mask(b7_crop, mask)
-  b10_crop <- crop(b10, extent(mask))
+  b10_crop <- crop(b10, ext(mask)[1:4])
   b10_mascara <- mask(b10_crop, mask)
-  b11_crop <- crop(b11, extent(mask))
+  b11_crop <- crop(b11, ext(mask)[1:4])
   b11_mascara <- mask(b11_crop, mask)
-  RG_crop <- crop(RG, extent(mask))
+  RG_crop <- crop(RG, ext(mask)[1:4])
   RG <- mask(RG_crop, mask)
-  ET0_crop <- crop(ET0, extent(mask))
+  ET0_crop <- crop(ET0, ext(mask)[1:4])
   ET0 <- mask(ET0_crop, mask)
-  Ta_crop <- crop(Ta, extent(mask))
+  Ta_crop <- crop(Ta, ext(mask)[1:4])
   Ta <- mask(Ta_crop, mask)
 
   metadata <- list.files(pattern = "txt")
@@ -709,11 +703,11 @@ radiation_l8t_grid =  function(doy, a, b){
   b11_mascara = ((RADIANCE_MAXIMUM_BAND_11-RADIANCE_MINIMUM_BAND_11)/65535)*b11_mascara+(RADIANCE_MINIMUM_BAND_11)
 
   lati <- long <- b2_mascara
-  xy <- coordinates(b2_mascara)
+  xy <- crds(b2_mascara)
   long[] <- xy[, 1]
-  long <- crop(long, extent(mask))
+  long <- crop(long, ext(mask)[1:4])
   lati[] <- xy[, 2]
-  lati <- crop(lati, extent(mask))
+  lati <- crop(lati, ext(mask)[1:4])
 
   map1 <- (long/long)*((2*pi)/365)*(doy-1)
 
@@ -764,11 +758,11 @@ radiation_l8t_grid =  function(doy, a, b){
   Alb_24 =  1.0223*Alb_sur + 0.0149
 
 
-  writeRaster(Alb_24, "Alb_24", format = "GTiff", overwrite=TRUE)
+  writeRaster(Alb_24, "Alb_24", filetype = "GTiff", overwrite=TRUE)
 
   NDVI =(b5_mascara-b4_mascara)/(b5_mascara+b4_mascara)
 
-  writeRaster(NDVI, "NDVI", format = "GTiff", overwrite=TRUE)
+  writeRaster(NDVI, "NDVI", filetype = "GTiff", overwrite=TRUE)
 
   Ws = acos(((-1)*tan(lati*pi/180))*tan(Dec))
 
@@ -789,7 +783,7 @@ radiation_l8t_grid =  function(doy, a, b){
 
   TS24 = 1.0694*Tbright-20.173
 
-  writeRaster(TS24, "LST", format = "GTiff", overwrite=TRUE)
+  writeRaster(TS24, "LST", filetype = "GTiff", overwrite=TRUE)
 
   Transm =(RG*11.6)/RsTOP
 
@@ -799,7 +793,7 @@ radiation_l8t_grid =  function(doy, a, b){
 
   Rn_MJ =Rn/11.6
 
-  writeRaster(Rn_MJ, "Rn_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(Rn_MJ, "Rn_MJ", filetype = "GTiff", overwrite=TRUE)
 
   rm(b1, b2, b3, b4, b5, b6, b7, b1_mascara, b2_mascara, b3_mascara, b4_mascara, b5_mascara,b6_mascara,b7_mascara, R, Ws, E0, cos_zwn, W, Dec, LAT, Et, map1, lati, long)
 
@@ -812,17 +806,17 @@ radiation_l8t_grid =  function(doy, a, b){
 
   LE_MJ =ET*2.45
 
-  writeRaster(LE_MJ, "LE_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(LE_MJ, "LE_MJ", filetype = "GTiff", overwrite=TRUE)
 
   G_Rn =3.98*exp(-25.47*Alb_24)
 
   G_MJ =G_Rn*Rn_MJ
 
-  writeRaster(G_MJ, "G_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(G_MJ, "G_MJ", filetype = "GTiff", overwrite=TRUE)
 
   H_MJ =Rn_MJ-LE_MJ-G_MJ
 
-  writeRaster(H_MJ, "H_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(H_MJ, "H_MJ", filetype = "GTiff", overwrite=TRUE)
 
 }
 
