@@ -9,9 +9,7 @@
 #' @param a  is one of the regression coefficients of SAFER algorithm
 #' @param b  is one of the regression coefficients of SAFER algorithm
 #' @export
-#' @import raster
-#' @import sp
-#' @import rgdal
+#' @import terra
 #' @importFrom utils read.csv
 #'
 #' @return It returns in raster format (.tif) the Surface Albedo at 24h scale ("Alb_24"), NDVI, Surface Temperature ("LST"), Crop Coefficient ("kc") and net radiation ("Rn_MJ").
@@ -19,10 +17,7 @@
 #' library(agriwater)
 #'
 #' # dependencies of package 'agriwater'
-#' library(sp)
-#' library(raster)
-#' library(rgdal)
-#' rgdal_show_exportToProj4_warnings"="none"
+#' library(terra)
 #'
 #'
 #' # Using a temporary folder to run example
@@ -35,42 +30,34 @@
 #' # https://drive.google.com/open?id=14E1wHNLxG7_Dh4I-GqNYakj8YJDgKLzk
 #'
 #' xy <- matrix(rnorm(4, mean = 0.07, sd = 0.01), 2, 2)
-#' rast <- raster(xy)
-#' extent(rast) <- c(-40.5,-40.45,-9.5,-9.45)
-#' projection(rast) <- CRS("+proj=longlat +datum=WGS84")
-#' writeRaster(rast, file.path(wd, "B2"),format = "GTiff", overwrite=TRUE)
+#' rast <- rast(xy, crs="+proj=longlat +datum=WGS84")
+#' ext(rast) <- c(-40.5,-40.45,-9.5,-9.45)
+#' writeRaster(rast, file.path(wd, "B2.tif"), filetype = "GTiff", overwrite=TRUE)
 #' xy <- matrix(rnorm(4, mean = 0.05, sd = 0.015),2, 2)
-#' rast <- raster(xy)
-#' extent(rast) <- c(-40.5,-40.45,-9.5,-9.45)
-#' projection(rast) <- CRS("+proj=longlat +datum=WGS84")
-#' writeRaster(rast, file.path(wd, "B1"),format = "GTiff", overwrite=TRUE)
+#' rast <- rast(xy, crs="+proj=longlat +datum=WGS84")
+#' ext(rast) <- c(-40.5,-40.45,-9.5,-9.45)
+#' writeRaster(rast, file.path(wd, "B1.tif"), filetype = "GTiff", overwrite=TRUE)
 #'
 #  # creating mask of study area
-#' mask <- as(extent(rast), 'SpatialPolygons')
-#' projection(mask) <- CRS("+proj=longlat +datum=WGS84")
-#' shapefile(mask, file.path(wd,"mask.shp"), overwrite=TRUE)
+#' mask <- as.polygons(rast)
+#' writeVector(mask, file.path(getwd(),"mask.shp"), overwrite=TRUE)
 #'
 #' # using "agriwater"
-#' DOY = 134
-#' a = 1.8
-#' b = -0.008
-#' RG = 17.6
-#' Ta = 27.9
-#' kc_modis(DOY, RG, Ta, a, b)
+#' kc_modis(doy = 134, RG = 17.6, Ta = 27.9, a = 1.8, b = -0.008)
 #'
 #' #Exiting temporary folder and returning to previous workspace
 #' setwd(initial)
 
 kc_modis = function(doy, RG, Ta, a, b){
 
-  b1 <- raster("B1.tif")
-  b2 <- raster("B2.tif")
+  b1 <- rast("B1.tif")
+  b2 <- rast("B2.tif")
 
-  mask <- readOGR("mask.shp")
+  mask <- vect("mask.shp")
 
-  b1_crop <- crop(b1, extent(mask))
+  b1_crop <- crop(b1, ext(mask)[1:4])
   b1_mascara <- mask(b1_crop, mask)
-  b2_crop <- crop(b2, extent(mask))
+  b2_crop <- crop(b2, ext(mask)[1:4])
   b2_mascara <- mask(b2_crop, mask)
 
 
@@ -79,18 +66,18 @@ kc_modis = function(doy, RG, Ta, a, b){
   Alb_24=1.0223*Alb_inst+ 0.0149
 
 
-  writeRaster(Alb_24, "Alb_24", format = "GTiff", overwrite=TRUE)
+  writeRaster(Alb_24, "Alb_24", filetype = "GTiff", overwrite=TRUE)
 
   NDVI =(b2_mascara-b1_mascara)/(b2_mascara+b1_mascara)
 
-  writeRaster(NDVI, "NDVI", format = "GTiff", overwrite=TRUE)
+  writeRaster(NDVI, "NDVI", filetype = "GTiff", overwrite=TRUE)
 
   lati <- long <- b2_mascara
-  xy <- coordinates(b2_mascara)
+  xy <- crds(b2_mascara)
   long[] <- xy[, 1]
-  long <- crop(long, extent(mask))
+  long <- crop(long, ext(mask)[1:4])
   lati[] <- xy[, 2]
-  lati <- crop(lati, extent(mask))
+  lati <- crop(lati, ext(mask)[1:4])
 
 
   map1 <- (long/long)*((2*pi)/365)*(doy-1)
@@ -123,7 +110,7 @@ kc_modis = function(doy, RG, Ta, a, b){
 
   Rn_MJ =Rn/11.6
 
-  writeRaster(Rn_MJ, "Rn_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(Rn_MJ, "Rn_MJ", filetype = "GTiff", overwrite=TRUE)
 
   slope =(4098*(0.6108*exp((17.27*(Ta))/((Ta)+237.3)))/((Ta)+237.3)^2)
 
@@ -157,13 +144,13 @@ kc_modis = function(doy, RG, Ta, a, b){
 
   TS24[TS24 < 273.15] = NA
 
-  writeRaster(TS24, "LST", format = "GTiff", overwrite=TRUE)
+  writeRaster(TS24, "LST", filetype = "GTiff", overwrite=TRUE)
 
   NDVI[NDVI <= 0] = NA
 
   kc=exp((a)+(b*((TS24-273.15)/(Alb_24*NDVI))))
 
-  writeRaster(kc, "kc", format = "GTiff", overwrite=TRUE)
+  writeRaster(kc, "kc", filetype = "GTiff", overwrite=TRUE)
 }
 
 #' Actual evapotranspiration (ETa) using MODIS with single agrometeorological data.
@@ -174,9 +161,7 @@ kc_modis = function(doy, RG, Ta, a, b){
 #' @param a  is one of the regression coefficients of SAFER algorithm
 #' @param b is one of the regression coefficients of SAFER algorithm
 #' @export
-#' @import raster
-#' @import sp
-#' @import rgdal
+#' @import terra
 #' @importFrom utils read.csv
 #'
 #' @return It returns in raster format (.tif) the Surface Albedo at 24h scale ("Alb_24"), NDVI, Surface Temperature ("LST"), net radiation ("Rn_MJ"), Crop Coefficient ("kc") and Actual Evapotranspiration (evapo).
@@ -184,10 +169,7 @@ kc_modis = function(doy, RG, Ta, a, b){
 #' library(agriwater)
 #'
 #' # dependencies of package 'agriwater'
-#' library(sp)
-#' library(raster)
-#' library(rgdal)
-#' rgdal_show_exportToProj4_warnings"="none"
+#' library(terra)
 #'
 #' # Using a temporary folder to run example
 #' wd <- tempdir()
@@ -199,47 +181,37 @@ kc_modis = function(doy, RG, Ta, a, b){
 #' # real data, please download:
 #' # https://drive.google.com/open?id=14E1wHNLxG7_Dh4I-GqNYakj8YJDgKLzk
 #'
-#' wd <- tempdir()
 #' xy <- matrix(rnorm(4, mean = 0.05, sd = 0.015),2, 2)
-#' rast <- raster(xy)
-#' extent(rast) <- c(-40.5,-40.45,-9.5,-9.45)
-#' projection(rast) <- CRS("+proj=longlat +datum=WGS84")
-#' writeRaster(rast, file.path(wd, "B2"),format = "GTiff", overwrite=TRUE)
+#' rast <- rast(xy, crs="+proj=longlat +datum=WGS84")
+#' ext(rast) <- c(-40.5,-40.45,-9.5,-9.45)
+#' writeRaster(rast, file.path(wd, "B2.tif"),filetype = "GTiff", overwrite=TRUE)
 #' xy <- matrix(rnorm(4, mean = 0.05, sd = 0.015),2, 2)
-#' rast <- raster(xy)
-#' extent(rast) <- c(-40.5,-40.45,-9.5,-9.45)
-#' projection(rast) <- CRS("+proj=longlat +datum=WGS84")
-#' writeRaster(rast, file.path(wd, "B1"),format = "GTiff", overwrite=TRUE)
+#' rast <- rast(xy, crs="+proj=longlat +datum=WGS84")
+#' ext(rast) <- c(-40.5,-40.45,-9.5,-9.45)
+#' writeRaster(rast, file.path(wd, "B1.tif"),filetype = "GTiff", overwrite=TRUE)
 #'
 #  # creating mask of study area
-#' mask <- as(extent(rast), 'SpatialPolygons')
-#' projection(mask) <- CRS("+proj=longlat +datum=WGS84")
-#' shapefile(mask, file.path(wd,"mask.shp"), overwrite=TRUE)
+#' mask <- as.polygons(rast)
+#' writeVector(mask, file.path(getwd(),"mask.shp"), overwrite=TRUE)
 #'
 #' # using "agriwater" - it's the same procedure as the used for
 #' # evapo_l8(), evapo_l8t(), evapo_modis_grid(), evapo_l8_grid(),
 #' # evapo_l8t_grid(), evapo_s2() and evapo_s2_grid()
-#' DOY = 134
-#' a = 1.8
-#' b = -0.008
-#' RG = 17.6
-#' Ta = 27.9
-#' ET0 = 3.8
-#' evapo_modis(DOY, RG, Ta, ET0, a, b)
+#' evapo_modis(doy = 134, RG = 17.6, Ta = 27.9, ET0 = 3.8, a = 1.8, b = -0.008)
 #'
 #' #Exiting temporary folder and returning to previous workspace
 #' setwd(initial)
 
 evapo_modis = function(doy, RG, Ta, ET0, a, b){
 
-  b1 <- raster("B1.tif")
-  b2 <- raster("B2.tif")
+  b1 <- rast("B1.tif")
+  b2 <- rast("B2.tif")
 
-  mask <- readOGR("mask.shp")
+  mask <- vect("mask.shp")
 
-  b1_crop <- crop(b1, extent(mask))
+  b1_crop <- crop(b1, ext(mask)[1:4])
   b1_mascara <- mask(b1_crop, mask)
-  b2_crop <- crop(b2, extent(mask))
+  b2_crop <- crop(b2, ext(mask)[1:4])
   b2_mascara <- mask(b2_crop, mask)
 
 
@@ -247,19 +219,19 @@ evapo_modis = function(doy, RG, Ta, ET0, a, b){
 
   Alb_24=1.0223*Alb_inst+ 0.0149
 
-  writeRaster(Alb_24, "Alb_24", format = "GTiff", overwrite=TRUE)
+  writeRaster(Alb_24, "Alb_24", filetype = "GTiff", overwrite=TRUE)
 
   NDVI =(b2_mascara-b1_mascara)/(b2_mascara+b1_mascara)
 
-  writeRaster(NDVI, "NDVI", format = "GTiff", overwrite=TRUE)
+  writeRaster(NDVI, "NDVI", filetype = "GTiff", overwrite=TRUE)
 
 
   lati <- long <- b2_mascara
-  xy <- coordinates(b2_mascara)
+  xy <- crds(b2_mascara)
   long[] <- xy[, 1]
-  long <- crop(long, extent(mask))
+  long <- crop(long, ext(mask)[1:4])
   lati[] <- xy[, 2]
-  lati <- crop(lati, extent(mask))
+  lati <- crop(lati, ext(mask)[1:4])
 
 
   map1 <- (long/long)*((2*pi)/365)*(doy-1)
@@ -292,7 +264,7 @@ evapo_modis = function(doy, RG, Ta, ET0, a, b){
 
   Rn_MJ =Rn/11.6
 
-  writeRaster(Rn_MJ, "Rn_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(Rn_MJ, "Rn_MJ", filetype = "GTiff", overwrite=TRUE)
 
   slope =(4098*(0.6108*exp((17.27*(Ta))/((Ta)+237.3)))/((Ta)+237.3)^2)
 
@@ -326,17 +298,17 @@ evapo_modis = function(doy, RG, Ta, ET0, a, b){
 
   TS24[TS24 < 273.15] = NA
 
-  writeRaster(TS24, "LST", format = "GTiff", overwrite=TRUE)
+  writeRaster(TS24, "LST", filetype = "GTiff", overwrite=TRUE)
 
   NDVI[NDVI <= 0] = NA
 
   kc=exp((a)+(b*((TS24-273.15)/(Alb_24*NDVI))))
 
-  writeRaster(kc, "kc", format = "GTiff", overwrite=TRUE)
+  writeRaster(kc, "kc", filetype = "GTiff", overwrite=TRUE)
 
   ET=kc*ET0
 
-  writeRaster(ET, "evapo", format = "GTiff", overwrite=TRUE)
+  writeRaster(ET, "evapo", filetype = "GTiff", overwrite=TRUE)
 }
 
 #'Energy balance using Landsat-8 images with single agrometeorological data.
@@ -347,9 +319,7 @@ evapo_modis = function(doy, RG, Ta, ET0, a, b){
 #'@param a is one of the regression coefficients of SAFER algorithm
 #'@param b is one of the regression coefficients of SAFER algorithm
 #'@export
-#'@import raster
-#' @import sp
-#' @import rgdal
+#' @import terra
 #' @importFrom utils read.csv
 #'
 #'@return It returns in raster format (.tif) the Surface Albedo at 24h scale ("Alb_24"), NDVI, Surface Temperature ("LST"), Crop Coefficient ("kc"), Actual Evapotranspiration (evapo), latent heat flux "LE_MJ"), net radiation ("Rn_MJ"), ground heat flux ("G_MJ") and the sensible heat flux ("H_MJ").
@@ -357,10 +327,7 @@ evapo_modis = function(doy, RG, Ta, ET0, a, b){
 #' library(agriwater)
 #'
 #' # dependencies of package 'agriwater'
-#' library(sp)
-#' library(raster)
-#' library(rgdal)
-#' rgdal_show_exportToProj4_warnings"="none"
+#' library(terra)
 #'
 #' # Using a temporary folder to run example
 #' wd <- tempdir()
@@ -371,35 +338,24 @@ evapo_modis = function(doy, RG, Ta, ET0, a, b){
 #' # real data, please download:
 #' # https://drive.google.com/open?id=14E1wHNLxG7_Dh4I-GqNYakj8YJDgKLzk
 #'
-#' wd <- tempdir()
-#' setwd <- tempdir()
 #' xy <- matrix(rnorm(4, mean = 0.05, sd = 0.015),2, 2)
-#' rast <- raster(xy)
-#' extent(rast) <- c(-40.5,-40.45,-9.5,-9.45)
-#' projection(rast) <- CRS("+proj=longlat +datum=WGS84")
-#' writeRaster(rast, file.path(wd, "B2"),format = "GTiff", overwrite=TRUE)
+#' rast <- rast(xy, crs="+proj=longlat +datum=WGS84")
+#' ext(rast) <- c(-40.5,-40.45,-9.5,-9.45)
+#' writeRaster(rast, file.path(wd, "B2.tif"),filetype = "GTiff", overwrite=TRUE)
 #' xy <- matrix(rnorm(4, mean = 0.05, sd = 0.015),2, 2)
-#' rast <- raster(xy)
-#' extent(rast) <- c(-40.5,-40.45,-9.5,-9.45)
-#' projection(rast) <- CRS("+proj=longlat +datum=WGS84")
-#' writeRaster(rast, file.path(wd, "B1"),format = "GTiff", overwrite=TRUE)
+#' rast <- rast(xy, crs="+proj=longlat +datum=WGS84")
+#' ext(rast) <- c(-40.5,-40.45,-9.5,-9.45)
+#' writeRaster(rast, file.path(wd, "B1.tif"),filetype = "GTiff", overwrite=TRUE)
 #'
 #' # creating mask of study area
-#' mask <- as(extent(rast), 'SpatialPolygons')
-#' projection(mask) <- CRS("+proj=longlat +datum=WGS84")
-#' shapefile(mask, file.path(wd,"mask.shp"), overwrite=TRUE)
+#' mask <- as.polygons(rast)
+#' writeVector(mask, file.path(getwd(),"mask.shp"), overwrite=TRUE)
 #'
 #' # using "agriwater" - it's the same procedure as the used for
 #' # radiation_l8(), radiation_l8t(), radiation_s2(),
 #' # radiation_l8_grid(), radiation_l8t_grid(),
 #' # radiation_s2_grid(), radiation_s2() and radiation_modis_grid()
-#' DOY = 134
-#' a = 1.8
-#' b = -0.008
-#' RG = 17.6
-#' Ta = 27.9
-#' ET0 = 3.8
-#' radiation_modis(DOY, RG, Ta, ET0, a, b)
+#' radiation_modis(doy = 134, RG = 17.6, Ta = 27.9, ET0 = 3.8, a = 1.8, b = -0.008)
 #'
 #' #Exiting temporary folder and returning to previous workspace
 #' setwd(initial)
@@ -407,14 +363,14 @@ evapo_modis = function(doy, RG, Ta, ET0, a, b){
 radiation_modis =  function(doy, RG, Ta, ET0, a, b){
 
 
-  b1 <- raster("B1.tif")
-  b2 <- raster("B2.tif")
+  b1 <- rast("B1.tif")
+  b2 <- rast("B2.tif")
 
-  mask <- readOGR("mask.shp")
+  mask <- vect("mask.shp")
 
-  b1_crop <- crop(b1, extent(mask))
+  b1_crop <- crop(b1, ext(mask)[1:4])
   b1_mascara <- mask(b1_crop, mask)
-  b2_crop <- crop(b2, extent(mask))
+  b2_crop <- crop(b2, ext(mask)[1:4])
   b2_mascara <- mask(b2_crop, mask)
 
 
@@ -422,19 +378,19 @@ radiation_modis =  function(doy, RG, Ta, ET0, a, b){
 
   Alb_24=1.0223*Alb_inst+ 0.0149
 
-  writeRaster(Alb_24, "Alb_24", format = "GTiff", overwrite=TRUE)
+  writeRaster(Alb_24, "Alb_24", filetype = "GTiff", overwrite=TRUE)
 
   NDVI =(b2_mascara-b1_mascara)/(b2_mascara+b1_mascara)
 
-  writeRaster(NDVI, "NDVI", format = "GTiff", overwrite=TRUE)
+  writeRaster(NDVI, "NDVI", filetype = "GTiff", overwrite=TRUE)
 
 
   lati <- long <- b2_mascara
-  xy <- coordinates(b2_mascara)
+  xy <- crds(b2_mascara)
   long[] <- xy[, 1]
-  long <- crop(long, extent(mask))
+  long <- crop(long, ext(mask)[1:4])
   lati[] <- xy[, 2]
-  lati <- crop(lati, extent(mask))
+  lati <- crop(lati, ext(mask)[1:4])
 
 
   map1 <- (long/long)*((2*pi)/365)*(doy-1)
@@ -467,7 +423,7 @@ radiation_modis =  function(doy, RG, Ta, ET0, a, b){
 
   Rn_MJ =Rn/11.6
 
-  writeRaster(Rn_MJ, "Rn_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(Rn_MJ, "Rn_MJ", filetype = "GTiff", overwrite=TRUE)
 
   slope =(4098*(0.6108*exp((17.27*(Ta))/((Ta)+237.3)))/((Ta)+237.3)^2)
 
@@ -501,7 +457,7 @@ radiation_modis =  function(doy, RG, Ta, ET0, a, b){
 
   TS24[TS24 < 273.15] = NA
 
-  writeRaster(TS24, "LST", format = "GTiff", overwrite=TRUE)
+  writeRaster(TS24, "LST", filetype = "GTiff", overwrite=TRUE)
 
   NDVI[NDVI <= 0] = NA
 
@@ -511,26 +467,24 @@ radiation_modis =  function(doy, RG, Ta, ET0, a, b){
 
   LE_MJ =ET*2.45
 
-  writeRaster(LE_MJ, "LE_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(LE_MJ, "LE_MJ", filetype = "GTiff", overwrite=TRUE)
 
   G_Rn =3.98*exp(-25.47*Alb_24)
 
   G_MJ =G_Rn*Rn_MJ
 
-  writeRaster(G_MJ, "G_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(G_MJ, "G_MJ", filetype = "GTiff", overwrite=TRUE)
 
   H_MJ =Rn_MJ-LE_MJ-G_MJ
 
-  writeRaster(H_MJ, "H_MJ", format = "GTiff", overwrite=TRUE)
+  writeRaster(H_MJ, "H_MJ", filetype = "GTiff", overwrite=TRUE)
 
 }
 
 #' Surface Albedo using MODIS images.
 #'
 #' @export
-#' @import raster
-#' @import sp
-#' @import rgdal
+#' @import terra
 #' @importFrom utils read.csv
 #'
 #' @return It returns in raster format (.tif) the Surface Albedo at 24h scale ("Alb_24").
@@ -538,10 +492,7 @@ radiation_modis =  function(doy, RG, Ta, ET0, a, b){
 #' library(agriwater)
 #'
 #' # dependencies of package 'agriwater'
-#' library(sp)
-#' library(raster)
-#' library(rgdal)
-#' rgdal_show_exportToProj4_warnings"="none"
+#' library(terra)
 #'
 #' # Using a temporary folder to run example
 #' wd <- tempdir()
@@ -552,23 +503,18 @@ radiation_modis =  function(doy, RG, Ta, ET0, a, b){
 #' # real data, please download:
 #' # https://drive.google.com/open?id=14E1wHNLxG7_Dh4I-GqNYakj8YJDgKLzk
 #'
-#' wd <- tempdir()
-#' setwd <- tempdir()
 #' xy <- matrix(rnorm(4, mean = 0.05, sd = 0.015),2, 2)
-#' rast <- raster(xy)
-#' extent(rast) <- c(-40.5,-40.45,-9.5,-9.45)
-#' projection(rast) <- CRS("+proj=longlat +datum=WGS84")
-#' writeRaster(rast, file.path(wd, "B2"),format = "GTiff", overwrite=TRUE)
-#' xy <- matrix(rnorm(4, mean = 0.05, sd = 0.015),2, 2)
-#' rast <- raster(xy)
-#' extent(rast) <- c(-40.5,-40.45,-9.5,-9.45)
-#' projection(rast) <- CRS("+proj=longlat +datum=WGS84")
-#' writeRaster(rast, file.path(wd, "B1"),format = "GTiff", overwrite=TRUE)
+#' rast <- rast(xy, crs="+proj=longlat +datum=WGS84")
+#' ext(rast) <- c(-40.5,-40.45,-9.5,-9.45)
+#' writeRaster(rast, file.path(wd, "B2.tif"),filetype = "GTiff", overwrite=TRUE)
+#' xy <- matrix(rnorm(4, mean = 0.05, sd = 0.01),2, 2)
+#' rast <- rast(xy, crs="+proj=longlat +datum=WGS84")
+#' ext(rast) <- c(-40.5,-40.45,-9.5,-9.45)
+#' writeRaster(rast, file.path(wd, "B1.tif"),filetype = "GTiff", overwrite=TRUE)
 #'
 #' # creating mask of study area
-#' mask <- as(extent(rast), 'SpatialPolygons')
-#' projection(mask) <- CRS("+proj=longlat +datum=WGS84")
-#' shapefile(mask, file.path(wd,"mask.shp"), overwrite=TRUE)
+#' mask <- as.polygons(rast)
+#' writeVector(mask, file.path(getwd(),"mask.shp"), overwrite=TRUE)
 #'
 #' # using "agriwater"
 #' albedo_modis()
@@ -578,14 +524,14 @@ radiation_modis =  function(doy, RG, Ta, ET0, a, b){
 
 albedo_modis = function(){
 
-  b1 <- raster("B1.tif")
-  b2 <- raster("B2.tif")
+  b1 <- rast("B1.tif")
+  b2 <- rast("B2.tif")
 
-  mask <- readOGR("mask.shp")
+  mask <- vect("mask.shp")
 
-  b1_crop <- crop(b1, extent(mask))
+  b1_crop <- crop(b1, ext(mask)[1:4])
   b1_mascara <- mask(b1_crop, mask)
-  b2_crop <- crop(b2, extent(mask))
+  b2_crop <- crop(b2, ext(mask)[1:4])
   b2_mascara <- mask(b2_crop, mask)
 
 
@@ -593,7 +539,7 @@ albedo_modis = function(){
 
   Alb_24=1.0223*Alb_inst+ 0.0149
 
-  writeRaster(Alb_24, "Alb_24", format = "GTiff", overwrite=TRUE)
+  writeRaster(Alb_24, "Alb_24", filetype = "GTiff", overwrite=TRUE)
 }
 
 
